@@ -4,4 +4,8 @@ age = 17
 
 print(f'I\'m {age} years old.')
 
-print('This is my first python pacage.')
\ No newline at end of file
+print('This is my first python pacage.')
+
+import example_pkg
+
+print(example_pkg.name)
\ No newline at end of file
